@@ -1,23 +1,24 @@
 #-------------------------------------------------------------------------------
 # Copyright (c) 2019 OBiBa. All rights reserved.
-#  
+#
 # This program and the accompanying materials
 # are made available under the terms of the GNU Public License v3.0.
-#  
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------
 
-#' Open a connection with Mica and returns a Mica object.
-#' 
+#' Open a connection with Mica and returns a Mica object. When the two-factor
+#' authentication mechanism is enabled, the user will be prompt for one-time password input.
+#'
 #' @title Open connection with Mica
-#' 
+#'
 #' @return A Mica object.
 #' @param username User name in mica. Can be provided by "mica.username" option.
 #' @param password User password in mica. Can be provided by "mica.password" option.
-#' @param url Mica url or list of mica urls. Can be provided by "mica.url" option.
+#' @param url Mica url or list of mica urls. Can be provided by "mica.url" option. Secure http (https) connection is required.
 #' @param opts Curl options. Can be provided by "mica.opts" option.
-#' @examples 
+#' @examples
 #' \dontrun{
 #' # login using credentials from mica.username and mica.password options
 #' m <- mica.login("https://mica-demo.obiba.org")
@@ -27,30 +28,59 @@
 #' @export
 mica.login <- function(username=getOption("mica.username", "anonymous"), password=getOption("mica.password", "password"), url=getOption("mica.url"), opts=getOption("mica.opts", list())) {
   if (is.null(url)) stop("mica url is required", call.=FALSE)
+  micaUrl <- url
+  # if (startsWith(url, "http://localhost:8082")) {
+  #   micaUrl <- gsub("http://localhost:8082", "https://localhost:8445", url)
+  #   warning("Deprecation: connecting through secure http is required. Replacing http://localhost:8082 by https://localhost:8445.")
+  # } else if (startsWith(url, "http://")) {
+  #   stop("Deprecation: connecting through secure http is required.")
+  # }
+  urlObj <- httr::parse_url(micaUrl)
+  # add a echo so I can see the url
+
   mica <- new.env(parent=globalenv())
   # Username
   mica$username <- username
   # Strip trailing slash
-  mica$url <- sub("/$", "", url)
+  mica$url <- sub("/$", "", micaUrl)
   # Domain name
-  mica$name <- gsub("[:/].*", "", gsub("http[s]*://", "", mica$url))
+  mica$name <- urlObj$hostname
   # Version default value
   mica$version <- NA
   # Authorization
   mica$authorization <- .authToken(username, password)
   class(mica) <- "mica"
-  
-  r <- GET(.url(mica, "config"), httr::add_headers(Authorization = mica$authorization), .verbose())
+
+  options <- opts
+  if (urlObj$hostname == "localhost" && length(options) == 0) {
+    options <- list(ssl_verifyhost=F, ssl_verifypeer=F)
+  }
+
+  mica$httrConfig <- config()
+  mica$httrConfig$options <- options
+  r <- GET(.url(mica, "config"), config = mica$httrConfig, httr::add_headers(Authorization = mica$authorization), .verbose())
+
+  if (httr::status_code(r) == 401) {
+    headers <- httr::headers(r)
+    optHeader <- headers[tolower('WWW-Authenticate')]
+    if (optHeader == 'X-Obiba-TOTP') {
+        cat("Has TOTP\n")
+
+      # TOTP code is required
+      code <- readline(prompt = 'Enter 6-digits code: ')
+      r <- GET(.url(mica, "config"), config = mica$httrConfig, httr::add_headers(Authorization = mica$authorization, 'X-Obiba-TOTP' = code), .verbose())
+    }
+  }
   mica$config <- .handleResponse(mica, r)
-  
+
   mica
 }
 
 #' Close connection and release resources of Mica.
-#' 
+#'
 #' @title Close connection with Mica
 #' @param mica A Mica object
-#' @examples 
+#' @examples
 #' \dontrun{
 #' m <- mica.login("https://mica-demo.obiba.org")
 #' mica.logout(m)
@@ -58,9 +88,9 @@ mica.login <- function(username=getOption("mica.username", "anonymous"), passwor
 #' @export
 mica.logout <- function(mica) {
   if (getOption("verbose", FALSE)) {
-    r <- DELETE(.url(mica, "auth", "session", "_current"), httr::verbose())
+    r <- DELETE(.url(mica, "auth", "session", "_current"), config = mica$httrConfig, httr::verbose())
   } else {
-    r <- DELETE(.url(mica, "auth", "session", "_current"))
+    r <- DELETE(.url(mica, "auth", "session", "_current"), config = mica$httrConfig)
   }
   mica$sid <- NULL
 }
@@ -149,7 +179,7 @@ print.mica <- function(x, ...) {
           if (is.null(rval[[subn]])) {
             rval[[subn]] <- subct[[subn]]
           } else {
-            rval[[subn]] <- paste0(rval[[subn]], "|", subct[[subn]])  
+            rval[[subn]] <- paste0(rval[[subn]], "|", subct[[subn]])
           }
         }
       }
@@ -169,7 +199,7 @@ print.mica <- function(x, ...) {
           rval[[k]] <- subct[[subn]]
         }
       }
-    }  
+    }
   }
   rval
 }
@@ -189,7 +219,7 @@ print.mica <- function(x, ...) {
 #' @import httr
 #' @keywords internal
 .get <- function(mica, ..., query=list()) {
-  r <- GET(.url(mica, ...), query=query, .verbose())
+  r <- GET(.url(mica, ...), config = mica$httrConfig, query=query, .verbose())
   .handleResponse(mica, r)
 }
 
@@ -197,7 +227,7 @@ print.mica <- function(x, ...) {
 #' @import httr
 #' @keywords internal
 .post <- function(mica, ..., query=list()) {
-  r <- POST(.url(mica, ...), body=query, encode=c("form"), .verbose())
+  r <- POST(.url(mica, ...), config = mica$httrConfig, body=query, encode=c("form"), .verbose())
   .handleResponse(mica, r)
 }
 
@@ -208,6 +238,8 @@ print.mica <- function(x, ...) {
   if (is.null(mica$version) || is.na(mica$version)) {
     headers <- httr::headers(response)
     mica$version <- as.character(headers[tolower('X-Mica-Version')])
+    versionInfo <- scan(text = mica$version, what = numeric(), sep = ".", n = 2)
+    mica$needsLegacySupport <- versionInfo[1] <= 5 && versionInfo[2] < 5
   }
   content <- content(response)
   if (response$status>=300) {
@@ -215,7 +247,7 @@ print.mica <- function(x, ...) {
       if ("message" %in% names(content)) {
         stop(content$message, call.=FALSE)
       } else {
-        stop(content$error, call.=FALSE)  
+        stop(content$error, call.=FALSE)
       }
     } else {
       stop(response$status, call.=FALSE)
