@@ -1,15 +1,15 @@
 #-------------------------------------------------------------------------------
 # Copyright (c) 2019 OBiBa. All rights reserved.
-#  
+#
 # This program and the accompanying materials
 # are made available under the terms of the GNU Public License v3.0.
-#  
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------
 
 #' Get the datasets
-#' 
+#'
 #' @title Get the datasets
 #' @param mica A Mica object
 #' @param query The search query
@@ -19,15 +19,15 @@
 #' @param limit Max number of items
 #' @param locale The language for labels (default is "en")
 #' @param df Return a data.frame (default is TRUE)
-#' @examples 
+#' @examples
 #' \dontrun{
 #' m <- mica.login("https://mica-demo.obiba.org")
 #' mica.datasets(m, query="variable(in(Mlstr_area.Lifestyle_behaviours,Drugs))")
 #' mica.logout(m)
 #' }
 #' @export
-mica.datasets <- function(mica, query="dataset()", 
-                          select=list("*"), sort=list("id"), 
+mica.datasets <- function(mica, query="dataset()",
+                          select=list("*"), sort=list("id"),
                           from=0, limit=10000, locale="en", df=TRUE) {
   q <- .append.rql(query, "dataset", select, sort, from, limit, locale)
   res <- .post(mica, "datasets", "_rql", query=list(query=q))
@@ -35,7 +35,8 @@ mica.datasets <- function(mica, query="dataset()",
     return(res)
   }
   .reportListMetrics(res)
-  summaries <- res[["datasetResultDto"]][["obiba.mica.DatasetResultDto.result"]][["datasets"]]
+  resultPropName <- ifelse(mica$needsLegacySupport, "obiba.mica.DatasetResultDto.result", "datasetResult")
+  summaries <- res[["datasetResultDto"]][[resultPropName]][["datasets"]]
   if (length(summaries)>0) {
     id <- rep(NA, length(summaries))
     name <- rep(NA, length(summaries))
@@ -58,15 +59,17 @@ mica.datasets <- function(mica, query="dataset()",
       description[i] <- .extractLabel(locale, d[["description"]])
       variableType[i] <- d[["variableType"]]
       entityType[i] <- d[["entityType"]]
-      if (!is.null(d[["obiba.mica.HarmonizedDatasetDto.type"]]) && !is.null(d[["obiba.mica.HarmonizedDatasetDto.type"]][["harmonizationTable"]])) {
+      harmonizedTypePropName <- ifelse(mica$needsLegacySupport, "obiba.mica.HarmonizedDatasetDto.type", "protocol")
+      collectedTypePropName <- ifelse(mica$needsLegacySupport, "obiba.mica.CollectedDatasetDto.type", "collected")
+      if (!is.null(d[[harmonizedTypePropName]]) && !is.null(d[[harmonizedTypePropName]][["harmonizationTable"]])) {
         hasStudyId <- TRUE
-        studyId[i] <- d[["obiba.mica.HarmonizedDatasetDto.type"]][["harmonizationTable"]][["studyId"]]
-        populationId[i] <- paste0(studyId[i], ":", d[["obiba.mica.HarmonizedDatasetDto.type"]][["harmonizationTable"]][["populationId"]])
-      } else if (!is.null(d[["obiba.mica.CollectedDatasetDto.type"]]) && !is.null(d[["obiba.mica.CollectedDatasetDto.type"]][["studyTable"]])) {
+        studyId[i] <- d[[harmonizedTypePropName]][["harmonizationTable"]][["studyId"]]
+        populationId[i] <- paste0(studyId[i], ":", d[[harmonizedTypePropName]][["harmonizationTable"]][["populationId"]])
+      } else if (!is.null(d[[collectedTypePropName]]) && !is.null(d[[collectedTypePropName]][["studyTable"]])) {
         hasStudyId <- TRUE
-        studyId[i] <- d[["obiba.mica.CollectedDatasetDto.type"]][["studyTable"]][["studyId"]]
-        populationId[i] <- paste0(studyId[i], ":", d[["obiba.mica.CollectedDatasetDto.type"]][["studyTable"]][["populationId"]])
-        dceId[i] <- d[["obiba.mica.CollectedDatasetDto.type"]][["studyTable"]][["dceId"]]
+        studyId[i] <- d[[collectedTypePropName]][["studyTable"]][["studyId"]]
+        populationId[i] <- paste0(studyId[i], ":", d[[collectedTypePropName]][["studyTable"]][["populationId"]])
+        dceId[i] <- d[[collectedTypePropName]][["studyTable"]][["dceId"]]
       }
       if (!is.null(d[["content"]])) {
         ct <- .flatten(jsonlite::fromJSON(d[["content"]], simplifyDataFrame = FALSE), locale)
@@ -79,7 +82,8 @@ mica.datasets <- function(mica, query="dataset()",
           model[[key]][i] <- ct[[key]]
         }
       }
-      counts <- d[["obiba.mica.CountStatsDto.datasetCountStats"]]
+      countsPropName <- ifelse(mica$needsLegacySupport, "obiba.mica.CountStatsDto.datasetCountStats", "countStats")
+      counts <- d[[countsPropName]]
       variables[i] <- .nullToNA(counts[["variables"]])
       networks[i] <- .nullToNA(counts[["networks"]])
     }
