@@ -1,15 +1,15 @@
 #-------------------------------------------------------------------------------
 # Copyright (c) 2019 OBiBa. All rights reserved.
-#  
+#
 # This program and the accompanying materials
 # are made available under the terms of the GNU Public License v3.0.
-#  
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------
 
 #' Get the networks
-#' 
+#'
 #' @title Get the networks
 #' @param mica A Mica object
 #' @param query The search query
@@ -19,15 +19,15 @@
 #' @param limit Max number of items
 #' @param locale The language for labels (default is "en")
 #' @param df Return a data.frame (default is TRUE)
-#' @examples 
+#' @examples
 #' \dontrun{
 #' m <- mica.login("https://mica-demo.obiba.org")
 #' mica.networks(m, query="network(in(Mica_network.studyIds,clsa))")
 #' mica.logout(m)
 #' }
 #' @export
-mica.networks <- function(mica, query="network()", 
-                          select=list("*"), sort=list("id"), 
+mica.networks <- function(mica, query="network()",
+                          select=list("*"), sort=list("id"),
                           from=0, limit=100, locale="en", df=TRUE) {
   q <- .append.rql(query, "network", select, sort, from, limit, locale)
   res <- .post(mica, "networks", "_rql", query=list(query=q))
@@ -35,7 +35,8 @@ mica.networks <- function(mica, query="network()",
     return(res)
   }
   .reportListMetrics(res)
-  summaries <- res[["networkResultDto"]][["obiba.mica.NetworkResultDto.result"]][["networks"]]
+  resultPropName <- ifelse(mica$needsLegacySupport, "obiba.mica.NetworkResultDto.result", "networkResult")
+  summaries <- res[["networkResultDto"]][[resultPropName]][["networks"]]
   if (length(summaries)>0) {
     id <- rep(NA, length(summaries))
     name <- rep(NA, length(summaries))
@@ -68,7 +69,8 @@ mica.networks <- function(mica, query="network()",
             model[[key]][i] <- ct[[key]]
           }
         }
-        counts <- n[["obiba.mica.CountStatsDto.networkCountStats"]]
+        countsPropName <- ifelse(mica$needsLegacySupport, "obiba.mica.CountStatsDto.networkCountStats", "countStats")
+        counts <- n[[countsPropName]]
         studies[i] <- .nullToNA(counts[["studies"]])
         variables[i] <- .nullToNA(counts[["variables"]])
         collectedDatasets[i] <- .nullToNA(counts[["studyDatasets"]])
