@@ -1,15 +1,15 @@
 #-------------------------------------------------------------------------------
 # Copyright (c) 2019 OBiBa. All rights reserved.
-#  
+#
 # This program and the accompanying materials
 # are made available under the terms of the GNU Public License v3.0.
-#  
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-------------------------------------------------------------------------------
 
 #' Get the study populations. Note that the populations are not fetched directly, they are extracted from study search results.
-#' 
+#'
 #' @title Get the study populations
 #' @family studies functions
 #' @param mica A Mica object
@@ -20,7 +20,7 @@
 #' @param limit Max number of items. Note that this limit applies to the studies that are fetched, the resulting count of populations will be higher.
 #' @param locale The language for labels (default is "en")
 #' @param df Return a data.frame (default is TRUE)
-#' @examples 
+#' @examples
 #' \dontrun{
 #' m <- mica.login("https://mica-demo.obiba.org")
 #' mica.study.populations(m, query="study(in(Mica_study.methods-design,cohort_study))")
@@ -28,8 +28,8 @@
 #' }
 #' @export
 mica.study.populations <- function(mica, query="study()",
-                         select=list("populations.name","populations.description","populations.model"), 
-                         sort=list("id"), 
+                         select=list("populations.name","populations.description","populations.model"),
+                         sort=list("id"),
                          from=0, limit=100, locale="en", df=TRUE) {
   q <- .append.rql(query, "study", select, sort, from, limit, locale)
   res <- .post(mica, "studies", "_rql", query=list(query=q))
@@ -37,7 +37,8 @@ mica.study.populations <- function(mica, query="study()",
     return(res)
   }
   .reportListMetrics(res)
-  summaries <- res[["studyResultDto"]][["obiba.mica.StudyResultDto.result"]][["summaries"]]
+  resultPropName <- ifelse(mica$needsLegacySupport, "obiba.mica.StudyResultDto.result", "studyResult")
+  summaries <- res[["studyResultDto"]][[resultPropName]][["summaries"]]
   if (length(summaries)>0) {
     # get the count of populations
     populationsCount <- 0
